
package jworms.game.explosion;

import jworms.game.GameField;
import jworms.openGL.SmallTexture;
import jworms.util.MathUtil;
import org.lwjgl.opengl.GL;

import java.awt.*;
import java.awt.geom.Point2D;

public class ExplosionCloud extends ExplosionObject{
// static
  /** Could texture. */
  private static SmallTexture texture = null;

  /**
   * Loads textures and sound.
   */
  public static void init(){
    // load images
    try{
      texture = new SmallTexture("images/explosion/cloud.png", GL.GL_LINEAR);
    } catch(Exception e){
      System.out.println("Error in ExplosionCloud during loading images.");
      e.printStackTrace();
    }
  }

// non static
  /** Scale factor. */
  float scaleFactor = .5f;
  /** Alpha factor. */
  float alphaFactor = .5f;

  /** Angle */
  protected float angle = 0;
  /** Rotation */
  protected float rotation = 0;

  /**
   * Creates an explosion cloud.
   *
   * @param gameField game field
   * @param position position
   * @param motion motion
   */
  public ExplosionCloud(GameField gameField, Point2D.Float position, Point2D.Float motion){
    super(gameField, position, motion);

    maxLife = 1;
    angle = (float) (Math.random() * 2 * Math.PI);
    rotation = (float) (Math.random() * 2 * Math.PI / 8);
  }

  protected void move(){
    position.x += motion.x;
    position.y += motion.y;
  }

  public void draw(){
    GL.glColor4f(1.0f, 1.0f, 1.0f, MathUtil.inBounds(0, 1 - (float) Math.pow(lifeSeconds / maxLife, 2), 1) * alphaFactor);

    Point screen = gameField.fieldToScreen((int) position.x, (int) position.y);
    screen.x -= texture.getImage().getWidth() / 2;
    screen.y -= texture.getImage().getHeight() / 2;

    float scale = (float) (Math.pow(lifeSeconds / maxLife, 0.2) + lifeSeconds / maxLife / 4) * scaleFactor;
    getTexture().draw(screen.x, screen.y, scale, scale, (float) ((angle + rotation * lifeSeconds) * 180 / Math.PI));
  }

  /**
   * Returns the texture.
   *
   * @return texture
   */
  public SmallTexture getTexture(){
    return texture;
  }

  public boolean isFinished(){
    return lifeSeconds > maxLife;
  }

  public void dispose(){
  }
}
