
package jworms.game.weapons;

import jworms.game.GameField;
import jworms.game.GameFieldUtil;
import jworms.game.GameObject;
import jworms.game.util.CollosionEnvironment;
import jworms.game.util.CollosionUtil;

import java.awt.geom.Point2D;
import java.awt.geom.Rectangle2D;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

public class Bullet extends Ball{
// static
  /** ID for the object class. */
  private static int classID = 0;
  public int getClassID() { return classID; }
  public void setClassID(int id) { classID = id; }

  /**
   * Loads textures and sound.
   */
  public static void init(){
    BulletUI.init();

    // register class id
    GameField.registerClass(new Bullet(true, null, null, null));
  }

// non static
  /** Start time. */
  protected long startTime = 0;
  /** Life time in seconds. */
  protected float lifeTime = 5;

  /** Damage radius. */
  protected int damageRadius = 5;

  public Bullet(boolean isHologram, GameField gameField, Point2D.Float position, Point2D.Float motion){
    this(isHologram, gameField, position, motion, 5);
  }

  public Bullet(boolean isHologram, GameField gameField, Point2D.Float position, Point2D.Float motion, int damageRadius){
    super(isHologram, gameField, position, motion);

    this.damageRadius = damageRadius;

    setUI(new BulletUI(this, gameField));

    startTime = System.currentTimeMillis();
  }

  /**
   * Sets the life time of this grenade.
   *
   * @param seconds life time
   */
  public void setLifeTime(float seconds){
    lifeTime = seconds;
  }

  public void doAction(){
    gameField.removeGameObject(this);

    getUI().hitOnGround(2.0f);
  }

  public void move(){
    CollosionEnvironment collosion = getUI().getCollosion();

    // calculate hit point with ground
    Rectangle2D.Float hitPoint = CollosionUtil.getHitPoint(position, motion, collosion, gameField);

    // explosion
    if(!isHologram && (hitPoint != null || (System.currentTimeMillis() - startTime) > lifeTime * 1000)){
      if(hitPoint != null){
        position.x = hitPoint.x;
        position.y = hitPoint.y;
      }
      // we want to explode
      hasAction = true;

      GameFieldUtil.doExplosion(gameField, (int) position.x, (int) position.y, damageRadius, Math.max(1, damageRadius / 5));
    } else{
      // ball motion
      position.x += motion.x;
      position.y += motion.y;
    }

    // gravity
    motion.y += GameField.GRAVITY / 2;

    // set angle
    angle = getMotionAngle();
  }

// network
  public GameObject create(GameField gameField, DataInputStream in) throws IOException{
    Bullet bullet = new Bullet(true, gameField, new Point2D.Float(), new Point2D.Float());
    bullet.recieveUpdate(in);
    return bullet;
  }

  public void sendUpdate(DataOutputStream out) throws IOException{
    super.sendUpdate(out);

    out.writeInt(damageRadius);
  }

  public void recieveUpdate(DataInputStream in) throws IOException{
    super.recieveUpdate(in);

    damageRadius = in.readInt();
  }
}
