
package jworms.game.weapons;

import jworms.game.GameField;
import jworms.game.GameObject;
import jworms.game.Player;
import jworms.game.explosion.Explosion;
import jworms.game.explosion.FlameExplosion;

import java.awt.geom.Point2D;
import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

public class Grenade extends Ball{
// static
  /** ID for the object class. */
  private static int classID = 0;
  public int getClassID() { return classID; }
  public void setClassID(int id) { classID = id; }

  /**
   * Loads textures and sound.
   */
  public static void init(){
    GrenadeUI.init();

    // register class id
    GameField.registerClass(new Grenade(true, null, null, null));
  }

// non static
  /** Life time in seconds. */
  private float lifeTime = 5;

  public Grenade(boolean isHologram, GameField gameField, Point2D.Float position, Point2D.Float motion){
    super(isHologram, gameField, position, motion);

    setUI(new GrenadeUI(this, gameField));
  }

  /**
   * Sets the life time of this grenade.
   *
   * @param seconds life time
   */
  public void setLifeTime(float seconds){
    lifeTime = seconds;
  }

  public void doAction(){
    gameField.removeGameObject(this);
  }

  public void move(){
    super.move();

    // explosion
    if(!isHologram && (System.currentTimeMillis() - startTime) > lifeTime * 1000){
      Point2D.Float explosionPosition = new Point2D.Float(getPosition().x, getPosition().y);
      Explosion explosion = new Explosion(false, gameField, explosionPosition);
      gameField.addGameObject(explosion);

      FlameExplosion flameExplosion = new FlameExplosion(false, gameField, explosionPosition);
      gameField.addGameObject(flameExplosion);

      // we want to explode
      hasAction = true;
    }
  }

// Weapon interface methods
  public Grenade(GameField gameField){
    super(gameField);

    setUI(new GrenadeUI(this, gameField));
  }

  public GameObject fireWeapon(Player player, GameField gameField){
    Ball ball = (Ball) super.fireWeapon(player, gameField);

    return new Grenade(false, gameField, ball.getPosition(), ball.getMotion());
  }

// network
  public GameObject create(GameField gameField, DataInputStream in) throws IOException{
    Grenade grenade = new Grenade(true, gameField, new Point2D.Float(), new Point2D.Float());
    grenade.recieveUpdate(in);
    return grenade;
  }

  public void sendUpdate(DataOutputStream out) throws IOException{
    super.sendUpdate(out);
  }

  public void recieveUpdate(DataInputStream in) throws IOException{
    super.recieveUpdate(in);
  }
}
