
package jworms.game.weapons;

import jworms.game.GameField;
import jworms.game.GameObject;
import jworms.game.Player;
import jworms.openGL.SmallTexture;
import org.lwjgl.opengl.GL;

import java.awt.*;
import java.awt.geom.Point2D;

public class RocketLauncher extends DesertEagle{
// static
  /** Texture for the weapon. */
  private static SmallTexture weaponTexture = null;

  /**
   * Loads textures and sound.
   */
  public static void init(){
    // load images
    try{
      weaponTexture = new SmallTexture("images/weapons/rocketlauncher/launcher.png", GL.GL_LINEAR);
    } catch(Exception e){
      System.out.println("Error in RocketLauncher during loading images.");
      e.printStackTrace();
    }
  }

// non static
  public RocketLauncher(GameField gameField){
    super(gameField);

    // Center of the weapon in texture coordinates
    relativeWeaponCenter = new Point(16, 7);
    // Position of the weapon center relative to the position of the Player
    relativeWeaponCenterPosition = new Point(16, 12);
    // Distance between the weapon center and the barrel center
    gripBarrelDistance = -3;
  }

  public SmallTexture getTexture(){
    return weaponTexture;
  }

  protected float getShootAngle(Player player){
    return player.getAimingAngle() + ((float) Math.random() - 0.5f) / 10;
  }

  public GameObject fireWeapon(Player player, GameField gameField){
    if(!isReady()) return null;

    // loops till next shoot
    loopsTillReady = 30;

    // calculate bullet
    float speed = player.getChargingValue() * 10;

    float angle = getShootAngle(player);
    float dx = (float) Math.cos(angle) * (player.getLookDirection() == Player.DIRECTION_RIGHT ? 1 : -1);
    float dy = (float) -Math.sin(angle);

    Point position = getCenter(player);
    position.x += dx * 10;
    position.y += dy * 10;

    Point2D.Float motion = new Point2D.Float(dx * speed, dy * speed);

    return new Rocket(false, gameField, new Point2D.Float(position.x, position.y), motion);
  }

  public boolean needsCharging(){
    return true;
  }
}
